timezones
=========

A Python library that provides better selection of common timezones, can output
HTML and auto select the best timezone based on user's IP.

Visit http://doist.github.com/python-timezones/ for more information.


Author
------

Amir Salihefendic <http://amix.dk>
